==> TuxGuitar-0.2.tar.gz: TuxGuitar-0.2/src/org/herac/tuxguitar/gui/items/menu/CompositionMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.composition.ChangeInfoAction;
import org.herac.tuxguitar.gui.actions.composition.ChangeTempoAction;
import org.herac.tuxguitar.gui.actions.composition.ChangeTimeSignatureAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class CompositionMenuItem implements ItemContainer{
    private TablatureEditor tablatureEditor;
    private MenuItem compositionMenuItem;
    private Menu menu; 
    private MenuItem timeSignature;
    private MenuItem tempo;
    
    public CompositionMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.compositionMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }    
    
    public void showItems(){                        
        //--TIME SIGNATURE--
        this.timeSignature = new MenuItem(this.menu, SWT.PUSH);
        this.timeSignature.setImage(new Image(this.menu.getDisplay(), TuxGuitar.getResourcePath(this, "timesignature.png")));
        this.timeSignature.setText("&Time Signature");            
        this.timeSignature.addSelectionListener(TuxGuitar.instance().getAction(ChangeTimeSignatureAction.NAME));
        //--TEMPO--
        this.tempo = new MenuItem(this.menu, SWT.PUSH);
        this.tempo.setText("&Tempo");
        this.tempo.addSelectionListener(TuxGuitar.instance().getAction(ChangeTempoAction.NAME));
        //--SEPARATOR--
        new MenuItem(this.menu, SWT.SEPARATOR);   
        //--INFO--
        this.tempo = new MenuItem(this.menu, SWT.PUSH);
        this.tempo.setText("Properties");
        this.tempo.addSelectionListener(TuxGuitar.instance().getAction(ChangeInfoAction.NAME));
        
        this.compositionMenuItem.setText("&Composition");
        this.compositionMenuItem.setMenu(menu);
    }    
    
    public void update(){
        
    }
}

==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/gui/items/menu/CompositionMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.composition.ChangeInfoAction;
import org.herac.tuxguitar.gui.actions.composition.ChangeTempoAction;
import org.herac.tuxguitar.gui.actions.composition.ChangeTimeSignatureAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class CompositionMenuItem implements ItemContainer{
    private TablatureEditor tablatureEditor;
    private MenuItem compositionMenuItem;
    private Menu menu; 
    private MenuItem timeSignature;
    private MenuItem tempo;
    private MenuItem properties;
    
    public CompositionMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.compositionMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }    
    
    public void showItems(){                        
        //--TIME SIGNATURE--
        this.timeSignature = new MenuItem(this.menu, SWT.PUSH);
        this.timeSignature.setImage(new Image(this.menu.getDisplay(), TuxGuitar.getResourcePath(this, "timesignature.png")));    
        this.timeSignature.addSelectionListener(TuxGuitar.instance().getAction(ChangeTimeSignatureAction.NAME));
        //--TEMPO--
        this.tempo = new MenuItem(this.menu, SWT.PUSH);
        this.tempo.addSelectionListener(TuxGuitar.instance().getAction(ChangeTempoAction.NAME));
        //--SEPARATOR--
        new MenuItem(this.menu, SWT.SEPARATOR);   
        //--INFO--
        this.properties = new MenuItem(this.menu, SWT.PUSH);
        this.properties.addSelectionListener(TuxGuitar.instance().getAction(ChangeInfoAction.NAME));
        
        this.compositionMenuItem.setMenu(menu);
        
        this.loadProperties();
    }    
    
    public void update(){
        
    }
    

    public void loadProperties(){
        this.compositionMenuItem.setText(TuxGuitar.getProperty("composition"));
        this.timeSignature.setText(TuxGuitar.getProperty("composition.timesignature"));
        this.tempo.setText(TuxGuitar.getProperty("composition.tempo"));
        this.properties.setText(TuxGuitar.getProperty("composition.properties"));
    }    
}
